import { LoadingBarModule, LoadingBarService } from '@ngx-loading-bar/core';
import { Injectable, NgModule } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { _finally as _finally$1 } from 'rxjs/operator/finally';

class LoadingBarInterceptor {
    /**
     * @param {?} loadingBar
     */
    constructor(loadingBar) {
        this.loadingBar = loadingBar;
    }
    /**
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    intercept(req, next) {
        // https://github.com/angular/angular/issues/18155
        if (req.headers.has('ignoreLoadingBar')) {
            return next.handle(req.clone({ headers: req.headers.delete('ignoreLoadingBar') }));
        }
        const /** @type {?} */ r = next.handle(req);
        let /** @type {?} */ started = false;
        const /** @type {?} */ responseSubscribe = r.subscribe.bind(r);
        r.subscribe = (...args) => {
            this.loadingBar.start();
            started = true;
            return responseSubscribe(...args);
        };
        return _finally$1.call(r, () => started && this.loadingBar.complete());
    }
}
LoadingBarInterceptor.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
LoadingBarInterceptor.ctorParameters = () => [
    { type: LoadingBarService, },
];

class LoadingBarHttpClientModule {
}
LoadingBarHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule,
                    LoadingBarModule.forRoot(),
                ],
                exports: [
                    HttpClientModule,
                    LoadingBarModule,
                ],
                providers: [
                    { provide: HTTP_INTERCEPTORS, useClass: LoadingBarInterceptor, multi: true },
                ],
            },] },
];
/**
 * @nocollapse
 */
LoadingBarHttpClientModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { LoadingBarHttpClientModule, LoadingBarInterceptor as ɵa };
//# sourceMappingURL=http-client.js.map
